@@ -22,7 +22,8 @@ def main():
             else:
                 print "{}: {}".format(session_id, data)
                 print "Sending date"
-                out_socket.send_multipart([session_id,
+                out_socket.send_multipart(['message',
+                                           session_id,
                                            'The time now is: ' + str(datetime.datetime.now())])
     except KeyboardInterrupt:
         pass
